(function() {
	/*
	 * APICloud JavaScript Library
	 * Copyright (c) 2014 apicloud.com
	 */
	(function(window) {
		var u = {};
		var isAndroid = /android/gi.test(navigator.appVersion);
		var uzStorage = function uzStorage() {
			var ls = window.localStorage;
			if (isAndroid) {
				ls = os.localStorage();
			}
			return ls;
		};
		function parseArguments(url, data, fnSuc, dataType) {
			if (typeof data == "function") {
				dataType = fnSuc;
				fnSuc = data;
				data = undefined;
			}
			if (typeof fnSuc != "function") {
				dataType = fnSuc;
				fnSuc = undefined;
			}
			return {
				url: url,
				data: data,
				fnSuc: fnSuc,
				dataType: dataType
			};
		}
		u.trim = function(str) {
			if (String.prototype.trim) {
				return str == null ? "" : String.prototype.trim.call(str);
			} else {
				return str.replace(/(^\s*)|(\s*$)/g, "");
			}
		};
		u.trimAll = function(str) {
			return str.replace(/\s*/g, "");
		};
		u.isElement = function(obj) {
			return !!(obj && obj.nodeType == 1);
		};
		u.isArray = function(obj) {
			if (Array.isArray) {
				return Array.isArray(obj);
			} else {
				return obj instanceof Array;
			}
		};
		u.isEmptyObject = function(obj) {
			if (JSON.stringify(obj) === "{}") {
				return true;
			}
			return false;
		};
		u.addEvt = function(el, name, fn, useCapture) {
			if (!u.isElement(el)) {
				console.warn(
					"$api.addEvt Function need el param, el param must be DOM Element"
				);
				return;
			}
			useCapture = useCapture || false;
			if (el.addEventListener) {
				el.addEventListener(name, fn, useCapture);
			}
		};
		u.rmEvt = function(el, name, fn, useCapture) {
			if (!u.isElement(el)) {
				console.warn(
					"$api.rmEvt Function need el param, el param must be DOM Element"
				);
				return;
			}
			useCapture = useCapture || false;
			if (el.removeEventListener) {
				el.removeEventListener(name, fn, useCapture);
			}
		};
		u.one = function(el, name, fn, useCapture) {
			if (!u.isElement(el)) {
				console.warn(
					"$api.one Function need el param, el param must be DOM Element"
				);
				return;
			}
			useCapture = useCapture || false;
			var that = this;
			var cb = function cb() {
				fn && fn();
				that.rmEvt(el, name, cb, useCapture);
			};
			that.addEvt(el, name, cb, useCapture);
		};
		u.dom = function(el, selector) {
			if (arguments.length === 1 && typeof arguments[0] == "string") {
				if (document.querySelector) {
					return document.querySelector(arguments[0]);
				}
			} else if (arguments.length === 2) {
				if (!el) {
					console.error("error selector:" + selector);
				}
				if (el.querySelector) {
					return el.querySelector(selector);
				}
			}
		};
		u.domAll = function(el, selector) {
			if (arguments.length === 1 && typeof arguments[0] == "string") {
				if (document.querySelectorAll) {
					return document.querySelectorAll(arguments[0]);
				}
			} else if (arguments.length === 2) {
				if (el.querySelectorAll) {
					return el.querySelectorAll(selector);
				}
			}
		};
		u.byId = function(id) {
			return document.getElementById(id);
		};
		u.first = function(el, selector) {
			if (arguments.length === 1) {
				if (!u.isElement(el)) {
					console.warn(
						"$api.first Function need el param, el param must be DOM Element"
					);
					return;
				}
				return el.children[0];
			}
			if (arguments.length === 2) {
				return this.dom(el, selector + ":first-child");
			}
		};
		u.last = function(el, selector) {
			if (arguments.length === 1) {
				if (!u.isElement(el)) {
					console.warn(
						"$api.last Function need el param, el param must be DOM Element"
					);
					return;
				}
				var children = el.children;
				return children[children.length - 1];
			}
			if (arguments.length === 2) {
				return this.dom(el, selector + ":last-child");
			}
		};
		u.eq = function(el, index) {
			return this.dom(el, ":nth-child(" + index + ")");
		};
		u.not = function(el, selector) {
			return this.domAll(el, ":not(" + selector + ")");
		};
		u.prev = function(el) {
			if (!u.isElement(el)) {
				console.warn(
					"$api.prev Function need el param, el param must be DOM Element"
				);
				return;
			}
			var node = el.previousSibling;
			if (node.nodeType && node.nodeType === 3) {
				node = node.previousSibling;
				return node;
			}
		};
		u.next = function(el) {
			if (!u.isElement(el)) {
				console.warn(
					"$api.next Function need el param, el param must be DOM Element"
				);
				return;
			}
			var node = el.nextSibling;
			if (node.nodeType && node.nodeType === 3) {
				node = node.nextSibling;
				return node;
			}
		};
		u.closest = function(el, selector) {
			if (!u.isElement(el)) {
				console.warn(
					"$api.closest Function need el param, el param must be DOM Element"
				);
				return;
			}
			var doms, targetDom;
			var isSame = function isSame(doms, el) {
				var i = 0,
					len = doms.length;
				for (i; i < len; i++) {
					if (doms[i].isSameNode(el)) {
						return doms[i];
					}
				}
				return false;
			};
			var traversal = function traversal(el, selector) {
				doms = u.domAll(el.parentNode, selector);
				targetDom = isSame(doms, el);
				while (!targetDom) {
					el = el.parentNode;
					if (el != null && el.nodeType == el.DOCUMENT_NODE) {
						return false;
					}
					traversal(el, selector);
				}

				return targetDom;
			};

			return traversal(el, selector);
		};
		u.contains = function(parent, el) {
			var mark = false;
			if (el === parent) {
				mark = true;
				return mark;
			} else {
				do {
					el = el.parentNode;
					if (el === parent) {
						mark = true;
						return mark;
					}
				} while (el === document.body || el === document.documentElement);

				return mark;
			}
		};
		u.remove = function(el) {
			if (el && el.parentNode) {
				el.parentNode.removeChild(el);
			}
		};
		u.attr = function(el, name, value) {
			if (!u.isElement(el)) {
				console.warn(
					"$api.attr Function need el param, el param must be DOM Element"
				);
				return;
			}
			if (arguments.length == 2) {
				return el.getAttribute(name);
			} else if (arguments.length == 3) {
				el.setAttribute(name, value);
				return el;
			}
		};
		u.removeAttr = function(el, name) {
			if (!u.isElement(el)) {
				console.warn(
					"$api.removeAttr Function need el param, el param must be DOM Element"
				);
				return;
			}
			if (arguments.length === 2) {
				el.removeAttribute(name);
			}
		};
		u.hasCls = function(el, cls) {
			if (!u.isElement(el)) {
				console.warn(
					"$api.hasCls Function need el param, el param must be DOM Element"
				);
				return;
			}
			if (el.className.indexOf(cls) > -1) {
				return true;
			} else {
				return false;
			}
		};
		u.addCls = function(el, cls) {
			if (!u.isElement(el)) {
				console.warn(
					"$api.addCls Function need el param, el param must be DOM Element"
				);
				return;
			}
			if ("classList" in el) {
				el.classList.add(cls);
			} else {
				var preCls = el.className;
				var newCls = preCls + " " + cls;
				el.className = newCls;
			}
			return el;
		};
		u.removeCls = function(el, cls) {
			if (!u.isElement(el)) {
				console.warn(
					"$api.removeCls Function need el param, el param must be DOM Element"
				);
				return;
			}
			if ("classList" in el) {
				el.classList.remove(cls);
			} else {
				var preCls = el.className;
				var newCls = preCls.replace(cls, "");
				el.className = newCls;
			}
			return el;
		};
		u.toggleCls = function(el, cls) {
			if (!u.isElement(el)) {
				console.warn(
					"$api.toggleCls Function need el param, el param must be DOM Element"
				);
				return;
			}
			if ("classList" in el) {
				el.classList.toggle(cls);
			} else {
				if (u.hasCls(el, cls)) {
					u.removeCls(el, cls);
				} else {
					u.addCls(el, cls);
				}
			}
			return el;
		};
		u.val = function(el, val) {
			if (!u.isElement(el)) {
				console.warn(
					"$api.val Function need el param, el param must be DOM Element"
				);
				return;
			}
			if (arguments.length === 1) {
				switch (el.tagName) {
					case "SELECT":
						var value = el.options[el.selectedIndex].value;
						return value;
					case "INPUT":
						return el.value;
					case "TEXTAREA":
						return el.value;
				}
			}
			if (arguments.length === 2) {
				switch (el.tagName) {
					case "SELECT":
						el.options[el.selectedIndex].value = val;
						return el;
					case "INPUT":
						el.value = val;
						return el;
					case "TEXTAREA":
						el.value = val;
						return el;
				}
			}
		};
		u.prepend = function(el, html) {
			if (!u.isElement(el)) {
				console.warn(
					"$api.prepend Function need el param, el param must be DOM Element"
				);
				return;
			}
			el.insertAdjacentHTML("afterbegin", html);
			return el;
		};
		u.append = function(el, html) {
			if (!u.isElement(el)) {
				console.warn(
					"$api.append Function need el param, el param must be DOM Element"
				);
				return;
			}
			el.insertAdjacentHTML("beforeend", html);
			return el;
		};
		u.before = function(el, html) {
			if (!u.isElement(el)) {
				console.warn(
					"$api.before Function need el param, el param must be DOM Element"
				);
				return;
			}
			el.insertAdjacentHTML("beforebegin", html);
			return el;
		};
		u.after = function(el, html) {
			if (!u.isElement(el)) {
				console.warn(
					"$api.after Function need el param, el param must be DOM Element"
				);
				return;
			}
			el.insertAdjacentHTML("afterend", html);
			return el;
		};
		u.html = function(el, html) {
			if (!u.isElement(el)) {
				console.warn(
					"$api.html Function need el param, el param must be DOM Element"
				);
				return;
			}
			if (arguments.length === 1) {
				return el.innerHTML;
			} else if (arguments.length === 2) {
				el.innerHTML = html;
				return el;
			}
		};
		u.text = function(el, txt) {
			if (!u.isElement(el)) {
				console.warn(
					"$api.text Function need el param, el param must be DOM Element"
				);
				return;
			}
			if (arguments.length === 1) {
				return el.textContent;
			} else if (arguments.length === 2) {
				el.textContent = txt;
				return el;
			}
		};
		u.offset = function(el) {
			if (!u.isElement(el)) {
				console.warn(
					"$api.offset Function need el param, el param must be DOM Element"
				);
				return;
			}
			var sl = Math.max(
				document.documentElement.scrollLeft,
				document.body.scrollLeft
			);
			var st = Math.max(
				document.documentElement.scrollTop,
				document.body.scrollTop
			);

			var rect = el.getBoundingClientRect();
			return {
				l: rect.left + sl,
				t: rect.top + st,
				w: el.offsetWidth,
				h: el.offsetHeight
			};
		};
		u.css = function(el, css) {
			if (!u.isElement(el)) {
				console.warn(
					"$api.css Function need el param, el param must be DOM Element"
				);
				return;
			}
			if (typeof css == "string" && css.indexOf(":") > 0) {
				el.style && (el.style.cssText += ";" + css);
			}
		};
		u.cssVal = function(el, prop) {
			if (!u.isElement(el)) {
				console.warn(
					"$api.cssVal Function need el param, el param must be DOM Element"
				);
				return;
			}
			if (arguments.length === 2) {
				var computedStyle = window.getComputedStyle(el, null);
				return computedStyle.getPropertyValue(prop);
			}
		};
		u.jsonToStr = function(json) {
			if (typeof json === "object") {
				return JSON && JSON.stringify(json);
			}
		};
		u.strToJson = function(str) {
			if (typeof str === "string") {
				return JSON && JSON.parse(str);
			}
		};
		u.setStorage = function(key, value) {
			if (arguments.length === 2) {
				var v = value;
				if (typeof v == "object" || typeof v == "boolean") {
					v = JSON.stringify(v);
					v = "obj-" + v;
				} else {
					v = "str-" + v;
				}
				var ls = uzStorage();
				if (ls) {
					ls.setItem(key, v);
				}
			}
		};
		u.getStorage = function(key) {
			var ls = uzStorage();
			if (ls) {
				var v = ls.getItem(key);
				if (!v) {
					return;
				}
				if (v.indexOf("obj-") === 0) {
					v = v.slice(4);
					return JSON.parse(v);
				} else if (v.indexOf("str-") === 0) {
					return v.slice(4);
				}
			}
		};
		u.rmStorage = function(key) {
			var ls = uzStorage();
			if (ls && key) {
				ls.removeItem(key);
			}
		};
		u.clearStorage = function() {
			var ls = uzStorage();
			if (ls) {
				ls.clear();
			}
		};
		u.fixIos7Bar = function(el) {
			return u.fixStatusBar(el);
		};
		u.fixStatusBar = function(el) {
			if (!u.isElement(el)) {
				console.warn(
					"$api.fixStatusBar Function need el param, el param must be DOM Element"
				);
				return 0;
			}
			el.style.paddingTop = api.safeArea.top + "px";
			return el.offsetHeight;
		};
		u.fixTabBar = function(el) {
			if (!u.isElement(el)) {
				console.warn(
					"$api.fixTabBar Function need el param, el param must be DOM Element"
				);
				return 0;
			}
			el.style.paddingBottom = api.safeArea.bottom + "px";
			return el.offsetHeight;
		};
		u.toast = function(title, text, time) {
			var opts = {};
			var show = function show(opts, time) {
				api.showProgress(opts);
				setTimeout(function() {
					api.hideProgress();
				}, time);
			};
			if (arguments.length === 1) {
				var time = time || 500;
				if (typeof title === "number") {
					time = title;
				} else {
					opts.title = title + "";
				}
				show(opts, time);
			} else if (arguments.length === 2) {
				var time = time || 500;
				var text = text;
				if (typeof text === "number") {
					var tmp = text;
					time = tmp;
					text = null;
				}
				if (title) {
					opts.title = title;
				}
				if (text) {
					opts.text = text;
				}
				show(opts, time);
			}
			if (title) {
				opts.title = title;
			}
			if (text) {
				opts.text = text;
			}
			time = time || 500;
			show(opts, time);
		};
		u.post = function() /*url,data,fnSuc,dataType*/ {
			var argsToJson = parseArguments.apply(null, arguments);
			var json = {};
			var fnSuc = argsToJson.fnSuc;
			argsToJson.url && (json.url = argsToJson.url);
			argsToJson.data && (json.data = argsToJson.data);
			if (argsToJson.dataType) {
				var type = argsToJson.dataType.toLowerCase();
				if (type == "text" || type == "json") {
					json.dataType = type;
				}
			} else {
				json.dataType = "json";
			}
			json.method = "post";
			api.ajax(json, function(ret, err) {
				if (ret) {
					fnSuc && fnSuc(ret);
				}
			});
		};
		u.get = function() /*url,fnSuc,dataType*/ {
			var argsToJson = parseArguments.apply(null, arguments);
			var json = {};
			var fnSuc = argsToJson.fnSuc;
			argsToJson.url && (json.url = argsToJson.url);
			//argsToJson.data && (json.data = argsToJson.data);
			if (argsToJson.dataType) {
				var type = argsToJson.dataType.toLowerCase();
				if (type == "text" || type == "json") {
					json.dataType = type;
				}
			} else {
				json.dataType = "text";
			}
			json.method = "get";
			api.ajax(json, function(ret, err) {
				if (ret) {
					fnSuc && fnSuc(ret);
				}
			});
		};

		/*end*/

		window.$api = u;
	})(window);

	// app版本号
	var appVersion = "1.7.614";
	// 渠道市场
	var appChannel = "tencent";
	// 扩展api.setPrefs()、api.getPrefs()、removePrefs()使其支持直接存储、读取数组、对象字面量类型数据，调用方法：$api.setPrefs(key,value)、$api.getPrefs(key)、$api.removePrefs(key)
	(function(window) {
		if (!window.$api) {
			return;
		}
		$api.setPrefs = function(key, value) {
			if (arguments.length === 2) {
				var v = value;
				if (typeof v == "object" || typeof v == "boolean") {
					//（数组或对象字面量） || 布尔值
					v = JSON.stringify(v);
					v = "obj-" + v;
				} else {
					v = "str-" + v;
				}
				api.setPrefs({
					key: key,
					value: v
				});
			}
		};
		$api.getPrefs = function(key) {
			var v = api.getPrefs({
				sync: true,
				key: key
			});

			if (!v) {
				return;
			}
			if (v.indexOf("obj-") === 0) {
				v = v.slice(4);
				return JSON.parse(v);
			} else if (v.indexOf("str-") === 0) {
				return v.slice(4);
			}
		};
		$api.removePrefs = function(key) {
			if (key) {
				api.removePrefs({
					key: key
				});
			}
		};
	})(window);
	function getCommonParam() {
		var commonParam = "",
			systemType = api.systemType,
			deviceId = api.deviceId,
			model = api.deviceModel,
			systemVersion = api.systemVersion,
			channel = "";

		if (systemType == "ios") {
			//判断是否是ios平台
			isIos = true;

			channel = 0; //ios渠道id
		} else {
			isIos = false;

			channel = 1; //android渠道id
		}

		commonParam =
			"?app_version=" +
			appVersion +
			"&system=" +
			systemType +
			"&deviceId=" +
			deviceId +
			"&model=" +
			model +
			"&systemVersion=" +
			systemVersion +
			"&channel=" +
			channel +
			"&appChannel=" +
			appChannel;

		// 获取登录信息
		// 全局userInfo
		userInfo = $api.getPrefs("userInfo");
		// console.log('userInfo:'+$api.jsonToStr(userInfo));
		if (userInfo) {
			commonParam +=
				"&zxb_token=" + userInfo.zxb_token + "&zxb_id=" + userInfo.zxb_id;
		}

		var registrationId = $api.getStorage("registrationId");
		if (registrationId) {
			commonParam += "&registration_id=" + registrationId;
		}

		// var txBugly = api.require('txBugly');
		// txBugly.setUserValue({
		//     key: 'userInfo',
		//     value: commonParam
		// });

		console.log("commonParam:" + commonParam);

		return commonParam;
	}

	function ajaxRequest(opts) {
		var url = "https://www.zixueb.cn/appapi";
		opts.url = opts.needPrefixUrl === false ? opts.url : url + opts.url;

		// console.log(api.winName+' ajax url:' + opts.url)
		var complete = opts.complete,
			success = opts.success,
			error = opts.error,
			done = opts.done,
			autoHideLoading = opts.autoHideLoading,
			needReterror = opts.needReterror; //needReterror=true,即ret.error交由success回调处理

		if (opts.loading != false) {
			// 显示加载中
			showLoading(opts.loading);
		}
		api.ajax(opts, function(ret, err) {
			// 隐藏加载中
			if (autoHideLoading != false) {
				hideLoading();
			}
			// console.log('请求complete:'+new Date().toLocaleTimeString())
			complete && complete(opts, ret, err);
			if (ret) {
				// console.log('ajax请求数据成功：' + JSON.stringify(ret))
				if (
					ret.error &&
					ret.error != 1 &&
					ret.error != 30001 &&
					!(needReterror === true)
				) {
					// 服务器请求成功 && (非30001“需要重新登录”(30001，重新登录，页面内success回调中执行) && 未显示声明为needReterror:true)
					hideLoading();
					api.toast({
						msg: ret.msg,
						duration: 2000,
						location: "middle"
					});

					return;
				}

				// console.log('ajax请求成功:' + opts.url)
				success && success(ret);
			} else {
				// console.log('ajax请求数据失败：' + JSON.stringify(err))
				if (error) {
					error(err);
				} else {
					api.toast({
						msg: err.msg,
						duration: 4000,
						location: "middle"
					});
				}
			}
			// console.log('请求done:'+new Date().toLocaleTimeString())
			done && done(opts, ret, err);
		});
	}

	// 隐藏加载中提示层
	function hideLoading() {
		var loadingWrap = $api.dom(".loading-wrap");
		$api.remove(loadingWrap);
	}

	var Privacy = /*@__PURE__*/ (function(Component) {
		function Privacy(props) {
			Component.call(this, props);
			this.data = {
				title: "温馨提示",
				contentTitle: "欢迎使用自学帮!",
				content:
					'<div style="line-height:20px;font-size:14px;"><p>为了更好地为您提供课程及学习服务，保障您的个人隐私及权益，我们会根据您使用的功能需求，收集必要的用户信息，可能涉及设备存储权限、账号等相关信息。未经您的同意，我们不会从第三方获取、共享或对外提供您的信息。</p></div>',
				nodes:
					'<div style="line-height:20px;font-size:12px;">您可以查看阅读完整版<a href="widget://pages/privacypolicy.stml" style="color:#13afed;text-decoration:none;">《隐私协议》</a>、<a href="widget://pages/userpolicy.stml" style="color:#13afed;text-decoration:none;">《用户协议》</a></div>',
				disagree: "不同意",
				agree: "同意",
				isTipMode: false,
				showContentTtile: true,
				commonParam: {}
			};
		}

		if (Component) Privacy.__proto__ = Component;
		Privacy.prototype = Object.create(Component && Component.prototype);
		Privacy.prototype.constructor = Privacy;
		Privacy.prototype.apiready = function() {
			this.data.commonParam = getCommonParam();
		};
		Privacy.prototype.disagree = function() {
			if (this.data.isTipMode) {
				api.closeWidget({silent: true});
			} else {
				this.data.title = "温馨提示";
				this.data.content =
					'<div style="line-height:20px;font-size:14px;"><p>您的信息仅用于为您提供服务，我们坚决保障您的隐私信息安全。如果您仍不同意本隐私协议，很遗憾我们将无法继续为您提供服务。</p></div>';
				this.data.disagree = "不同意并退出";
				this.data.agree = "同意并继续";
				this.data.isTipMode = true;
				this.data.showContentTtile = false;
			}
		};
		Privacy.prototype.agree = function() {
			api.agreedPrivacy();
			this.saveUserAgreement();
		};
		Privacy.prototype.saveUserAgreement = function() {
			var optParam = "",
				deviceId = api.deviceId;
			optParam += "&device_code=" + deviceId;

			optParam += "&is_agree=1";
			ajaxRequest({
				url: "/v2/save_user_agreement.php" + this.data.commonParam + optParam,
				method: "get",
				cache: true,
				loading: false,
				success: function(ret) {
					console.log(JSON.stringify(ret));
				}
			});
		};
		Privacy.prototype.onInteract = function(e) {
			var url = e.detail.url;
			console.log(url);

			api.openWin({
				name: "privacy",
				url: url
			});

			// api.agreedPrivacy();
		};
		Privacy.prototype.render = function() {
			var this$1 = this;
			return apivm.h(
				"view",
				{class: "page"},
				apivm.h(
					"view",
					{class: "cover"},
					apivm.h(
						"view",
						{class: "box"},
						apivm.h("text", {class: "title"}, this.data.title),
						apivm.h(
							"scroll-view",
							{class: "content-area", bounces: false},
							this.data.showContentTtile
								? apivm.h("text", {class: "content-title"}, this.data.contentTitle)
								: null,
							apivm.h("rich-text", {class: "content", nodes: this.data.content}),
							apivm.h("rich-text", {
								class: "policy-area",
								nodes: this.data.nodes,
								"link-text-color": "#13afed",
								"user-select": true,
								oninteract: this.onInteract
							})
						),
						apivm.h(
							"view",
							{class: "btn-area"},
							apivm.h(
								"text",
								{
									class: "disagree",
									onclick: function(event) {
										if (this$1.disagree) {
											this$1.disagree();
										} else {
											disagree();
										}
									}
								},
								this.data.disagree
							),
							apivm.h("view", {class: "line"}),
							apivm.h(
								"text",
								{
									class: "agree",
									onclick: function(event) {
										if (this$1.agree) {
											this$1.agree();
										} else {
											agree();
										}
									}
								},
								this.data.agree
							)
						)
					)
				)
			);
		};

		return Privacy;
	})(Component);
	Privacy.css = {
		".page": {width: "100%", height: "100%"},
		".cover": {
			justifyContent: "center",
			alignItems: "center",
			width: "100%",
			height: "100%",
			backgroundColor: "rgba(0, 0, 0, 0.6)"
		},
		".box": {
			width: "80%",
			maxWidth: "360px",
			minHeight: "167px",
			maxHeight: "480px",
			backgroundColor: "white",
			borderRadius: "14px"
		},
		".title": {
			margin: "20px 15px 5px",
			color: "black",
			fontWeight: "bold",
			fontSize: "16px",
			textAlign: "center",
			whiteSpace: "normal"
		},
		".content-area": {minHeight: "90px", maxHeight: "400px", overflow: "scroll"},
		".content-title": {
			color: "black",
			fontWeight: "bold",
			fontSize: "16px",
			margin: "10px 15px 5px"
		},
		".content": {
			margin: "0 15px",
			color: "black",
			fontSize: "14px",
			whiteSpace: "normal"
		},
		".policy-area": {margin: "0 15px 10px", whiteSpace: "normal"},
		".btn-area": {
			flexDirection: "row",
			alignItems: "center",
			height: "40px",
			borderTop: "0.5px solid #f5f5f5"
		},
		".disagree": {
			flex: "1",
			textAlign: "center",
			lineHeight: "40px",
			color: "#555"
		},
		".disagree:active": {opacity: "0.8"},
		".line": {width: "0.5px", height: "28px", backgroundColor: "#f5f5f5"},
		".agree": {
			flex: "1",
			textAlign: "center",
			lineHeight: "40px",
			color: "#13afed"
		},
		".agree:active": {opacity: "0.8"}
	};
	apivm.define("privacy", Privacy);
	apivm.render(apivm.h("privacy", null), "body");
})();
