// app版本号
var appVersion = '1.7.614';
// 渠道市场
var appChannel = 'tencent';
// 扩展api.setPrefs()、api.getPrefs()、removePrefs()使其支持直接存储、读取数组、对象字面量类型数据，调用方法：$api.setPrefs(key,value)、$api.getPrefs(key)、$api.removePrefs(key)
(function (window) {
    if (!window.$api){
        return;
    }
    $api.setPrefs = function (key, value) {
        if (arguments.length === 2) {
            var v = value;
            if (typeof v == 'object' || typeof v == 'boolean') {//（数组或对象字面量） || 布尔值
                v = JSON.stringify(v);
                v = 'obj-' + v;
            } else {
                v = 'str-' + v;
            }
            api.setPrefs({
                key: key,
                value: v
            });
        }
    };
    $api.getPrefs = function (key) {
        var v = api.getPrefs({
            sync: true,
            key: key
        });
        if (!v) {
            return;
        }
        if (v.indexOf('obj-') === 0) {
            v = v.slice(4);
            return JSON.parse(v);
        } else if (v.indexOf('str-') === 0) {
            return v.slice(4);
        }
    };
    $api.removePrefs = function (key) {
        if (key) {
            api.removePrefs({
                key: key
            });
        }
    };
})(window);

function getCommonParam() {
    var commonParam = '',
        systemType = api.systemType,
        deviceId = api.deviceId,
        model = api.deviceModel,
        systemVersion = api.systemVersion,
        channel = '';

    if (systemType == 'ios') { //判断是否是ios平台
        isIos = true;

        channel = 0; //ios渠道id
    } else {
        isIos = false;

        channel = 1; //android渠道id
    }

    commonParam = '?app_version=' + appVersion + '&system=' + systemType + '&deviceId=' + deviceId + '&model=' + model + '&systemVersion=' + systemVersion + '&channel=' + channel + '&app_channel=' + appChannel;

    // 获取登录信息
    // 全局userInfo
    userInfo = $api.getPrefs('userInfo');
    // console.log('userInfo:'+$api.jsonToStr(userInfo));
    if (userInfo) {
        commonParam += '&zxb_token=' + userInfo.zxb_token + '&zxb_id=' + userInfo.zxb_id;
    }

    var registrationId = $api.getStorage('registrationId')
    if(registrationId) {
        commonParam += '&registration_id=' + registrationId;
    }

    // var txBugly = api.require('txBugly');
    // txBugly.setUserValue({
    //     key: 'userInfo',
    //     value: commonParam
    // });

    console.log('commonParam:'+commonParam);

    return commonParam;
}
/*
postdata_ 跟 接口公用的接口参数合并，供ajax发送post类型请求时使用;
未传参postdata_ ，返回以对象字面量格式返回commonParam;
return 数据结构
{
    values:{}
}
*/
function mergeCommonParam(postdata_) {
    var item = '',
        key = '',
        val = '';

    // 获取接口公用的接口参数
    var commonParam = getCommonParam();

    var postdata_ = postdata_;
    if (postdata_ == undefined) {
        postdata_ = {
            values: {}
        }
    }

    var commonParamArr = commonParam.split('&');
    commonParamArr[0] = commonParamArr[0].replace(/^\?/, '');
    // console.log('commonParamArr:'+$api.jsonToStr(commonParamArr));
    for (var i = 0, len = commonParamArr.length; i < len; i++) {
        item = commonParamArr[i].split('=');
        key = item[0];
        val = item[1];

        postdata_.values[key] = val;
    }

    return postdata_;
}
// 统一弹窗样式
function showConfirm(opt) {
    // dialogBox模块
    dialogBox = api.require('dialogBox');

    var content = opt.content,
        leftBtnTitle = opt.leftBtnTitle ? opt.leftBtnTitle : '取消',
        rightBtnTitle = opt.rightBtnTitle ? opt.rightBtnTitle : '确定',
        rightBtnColor = opt.rightBtnColor ? opt.rightBtnColor : '#2e2e2e',
        leftBtnCallback = opt.leftBtnCallback ? opt.leftBtnCallback : null,
        rightBtnCallback = opt.rightBtnCallback ? opt.rightBtnCallback : null;

    var params = {
        texts: {
            content: content,
            leftBtnTitle: leftBtnTitle,
            rightBtnTitle: rightBtnTitle
        },
        styles: {
            corner: 10,
            title: {
                marginT: 21,
                titleSize: 18,
                titleColor: '#2e2e2e'
            },
            content: {
                color: '#2e2e2e',
                size: 15,
                marginT: 30,
                marginB: 34
            },
            horizontalLine: {
                color: '#e6e6e6',
                height: 1
            }
        }
    };

    // 是否显示标题
    if (opt.title) {
        params.texts.title = opt.title;
    }

    if (leftBtnCallback) {
        params.styles.left = {
            marginB: 0,
            marginL: 0,
            w: 150,
            h: 48,
            corner: 10,
            color: '#2e2e2e',
            bg: '#fff',
            size: 17
        };
    }

    if (rightBtnCallback) {
        params.styles.right = {
            marginB: 0,
            marginL: 0,
            w: 150,
            h: 48,
            corner: 10,
            color: rightBtnColor,
            bg: '#fff',
            size: 17
        };
    }


    if (leftBtnCallback && !rightBtnCallback) { //只有左按钮
        params.styles.left.w = 300;
    } else if (rightBtnCallback && !leftBtnCallback) { //只有右按钮
        params.styles.right.w = 300;
    } else { //左右两两按钮
        // 两按钮间显示竖线分隔
        params.styles.verticalLine = {
            color: '#e6e6e6',
            height: 1
        }
    }

    dialogBox.alert(params, function (ret) {
        if (ret.eventType == 'right' && rightBtnCallback) {
            rightBtnCallback();
        } else if (ret.eventType == 'left' && leftBtnCallback) {
            leftBtnCallback();
        }

        dialogBox.close({
            dialogName: 'alert'
        });
    });
}
//断网事件
function offlineEvent(opts_) {
    var offlineHtml = '<div class="offlineTips dn">当前网络不可用，请检查你的网络设置。</div>';
    if (api.winName == 'login') {
        $api.after(header, offlineHtml);
    } else {
        $api.prepend(document.body, offlineHtml);
    }
    offlineTips = $api.dom('.offlineTips');

    // 专辑播放页、个人中心、vip专区起始页始终不显示offlineTips
    var isRemoveOfflineTips = api.winName == 'course_detail' || api.frameName ==
        'course_detail_frame' || api.frameName == 'course_catagory_frame' ||
        api.frameName == 'video_controlbar_frame' || api.frameName ==
        'personal_frame' || api.frameName == 'vip_home_frame';
    if (isRemoveOfflineTips) {
        $api.remove(offlineTips);
    }

    // 页面首次加载检查是否有网络
    // 页面首次加载完成后，才能监听到offline事件
    if (api.connectionType == 'none' && !(opts_ && opts_.hideInitToast)) {
        offlineFn();
    } else {
        isOffline = false;
    }

    api.addEventListener({
        name: 'offline'
    }, function (ret, err) {
        // alert($api.jsonToStr(ret));
        offlineFn(opts_);
    });
    api.addEventListener({
        name: 'online'
    }, function (ret, err) {
        // alert($api.jsonToStr(ret));
        onlineFn(opts_);
    });
}
// 无网络提示
function offlineFn(opts_) {
    isOffline = true;
    // alert(api.frameName);
    if (opts_ && opts_.offlineCallback) {
        opts_.offlineCallback();
    } else {
        api.toast({
            msg: '网络不可用',
            duration: 2000,
            location: 'middle'
        });
    }
    typeof offlineTips != 'undefined' && $api.removeCls(offlineTips, 'dn');
}
// 连网提示
function onlineFn(opts_) {
    var scrTop = document.body.scrollTop;
    isOffline = false;
    if (opts_ && opts_.onlineCallback) {
        opts_.onlineCallback();
    } else {
        api.toast({
            msg: '网络已连接',
            duration: 2000,
            location: 'middle'
        });
    }
    typeof offlineTips != 'undefined' && $api.addCls(offlineTips, 'dn');
    // 判断是否要刷新页面
    //不刷新页面：用户浏览到非第一屏页面、专辑播放页、
    // if(scrTop==0 && api.winName!='course_detail'){
    //     location.reload();
    // }
}
// 无网络重新加载提示
function showReloadTips() {
    if (typeof curPage == 'undefined' || curPage>1){//没设分页 || 当前分页非首页
        var reloadHtml = '<div class="offline tc">' +
            '<div class="img"></div>' + '<p>您的网络好像不太给力，请稍后重试</p>' +
            '<button type="button" name="button" onclick="javascript:location.reload();" class="btn reload-btn" tapmode="active">重新加载</button>' +
            '</div>';
        // console.log(reloadHtml);
        $api.html(document.body, reloadHtml);
    }else{
        api.toast({
            msg: '网络不可用',
            duration: 2000,
            location: 'middle'
        });
    }
    // 隐藏下载加载状态
    api.refreshHeaderLoadDone();
}

// 缩略图加入缓存
// thumbnail参数设为true,ios下会有"图片显示模糊"问题 && android下gif格式图片动画会无法展示
// callback_: 回调函数
function loadImg(ele_, callback_) {
    // (旧版)thumbnail参数设为true,ios下会有"图片显示模糊"问题需改设成false;但设为false,android下有"列表页加载比较多的图片，滑动页面时内容卡顿显示"现象,固要分平台设置thumbnail参数值：
    // android:true, ios:false
    // var thumbnailBoolean=api.systemType=='ios'?false:true,
    var thumbnailBoolean = false,
        dataurl = $api.attr(ele_, 'data-src');
    if (dataurl) {
        api.imageCache({
            url: dataurl,
            thumbnail: thumbnailBoolean,
            policy: 'cache_only' //加速图片缓存回显速度，服务器上传更换图片，图片文件名路径会更新！（不发请求，不对比图片是否有更新）
        }, function (ret, err) {
            // console.log(JSON.stringify(ret))
            ele_.src = ret.url;
            $api.removeCls(ele_, 'lazy');
            $api.addCls(ele_, 'imgloaded');

            // src赋值，也会触发onload，防止循环执行必须移除对应属性
            $api.removeAttr(ele_, 'data-src');
            $api.removeAttr(ele_, 'onload');

            callback_ && callback_(ele_);
        });

    }
}
// 显示加载中提示层
function showLoading(opt) {
    if (opt && opt.style === 2) {
        if (opt.mask) {
            var loadingHtml = '<div class="loading-wrap loading-style2 mask"><div class="loading2"></div></div>';
        } else {
            var loadingHtml = '<div class="loading-wrap loading-style2"><div class="loading2"></div></div>';
        }
    } else {
        // 有标题栏，加载层不能遮挡头部标题栏
        var headerH = typeof header != 'undefined' ? $api.offset(header).h : 0;
        if(opt && opt.noHeader){
            headerH=0;
        }
        var loadingHtml = '<div class="loading-wrap df ai-c tc" style="top:' + headerH + 'px;">' +
            '    <div class="loading-box pr">' +
            '        <div class="loading"></div>';
        if (opt && opt.text) {
            loadingHtml += '<p class="txt">' + opt.text + '</p>';

        }
        loadingHtml += '</div></div>';
    }

    // console.log(loadingHtml);

    // 防止重复append插入
    var loadingWrap = $api.dom('.loading-wrap');
    if (loadingWrap) return;

    $api.append(document.body, loadingHtml);
}
// 隐藏加载中提示层
function hideLoading() {
    var loadingWrap = $api.dom('.loading-wrap');
    $api.remove(loadingWrap);
}
// 获取当前设备类型
function getSystemType() {
    // 判断是否是ios平台
    if (api.systemType == 'ios') {
        isIos = true;
    } else {
        isIos = false;
    }

    // 获取是否是有刘海设备
    isFringeDevice = false;
    (function () {
        // iPhone X ：iPhone10,3
        // iPhone X ：iPhone10,6
        // iPhone XS ：iPhone11,2
        // iPhone XS Max ：iPhone11,4
        // iPhone XS Max ：iPhone11,6
        // iPhone XR ：iPhone11,8
        var deviceModel = api.deviceModel,
            fringeDevice = ['iPhone10,3', 'iPhone10,6', 'iPhone11,2', 'iPhone11,4', 'iPhone11,6', 'iPhone11,8'],
            saTop = api.safeArea.top;
        // console.log('deviceModel:'+deviceModel);
        // console.log('safeArea:'+$api.jsonToStr(api.safeArea));
        // console.log('saTop:'+saTop);
        for (var i = 0, len = fringeDevice.length; i < len; i++) {
            if (deviceModel == fringeDevice[i]) {
                isFringeDevice = true;
                break;
            } else if (saTop >= 44) { //非上述fringeDevice设备，再匹配safeArea，以匹配非苹果又带刘海的机型设备
                isFringeDevice = true;
                break;
            }
        }
        // console.log('isFringeDevice:'+isFringeDevice)


    })();
}
// 设置页面是否响应下拉刷新或上拉加载更多
// 参数boolean_
// true:设置响应
// false:禁止响应
function setPageBounces(boolean_) {
    api.setFrameAttr({
        name: api.frameName,
        bounces: boolean_
    });
}

// 数字超过一万，以万为单位返回数字
function getNumbers(num_) {
    if (num_ > 10000) {
        // 千位下浮动,如：1.21万 -> 1.2万
        // return parseInt(num_/10000*10)/10+'万';
        // 千位上浮动,如：1.21万 -> 1.3万
        return Math.ceil(num_ / 1000) / 10 + '万';
    } else {
        return num_;
    }
}
// 截取课程时长：不显示00秒、00分
// 截取课程时长：不显示00小时、00分、00秒;只有分时显示：xx分钟,如04分显示4分钟
function getStudyTime(str_) {
    // 不显示00小时、00分、00秒(正则ios不支持)
    // var result=str_.replace(/(?<!\d)00(小时|分|秒)/g,'');

    // 不显示00分、00秒
    var result = str_.replace(/00(分|秒)/g, '');

    // 只有分时显示：xx分钟
    result = result.replace(/^0?(\d+分)$/, '$1钟');

    return result;
}
// 两位数值相减或相加，保留2位小数点，小数点第2位上舍入
// add_：true 相加，否则为相减
function getFloatNum(num1_, num2_, add_) {
    var tempNum = '';
    if (add_ === true) {
        tempNum = num1_ + num2_
    } else {
        tempNum = num1_ - num2_
    }

    return Math.ceil(parseInt(tempNum * 1000) / 10) / 100
}
// 格式化输出价格，保留2位小数，不足补齐2位，无小数补齐.00输出
function formatPrice(price_) {
    // console.log('原始价格：'+price_);
    var price_ = String(price_);
    var result = price_.match(/(\d+)\.*(\d*)*/);
    var decimal = result[2];
    if (decimal) {
        decimal = decimal.length >= 2 ? decimal.slice(0, 2) : decimal + '0';
    } else {
        decimal = '00';
    }
    var price = result[1] + '.' + decimal;
    // console.log('格式化价格：' + price)
    return price;
}

// 直接调用外部浏览器
function openExternalBrowser(url_) {
    if (api.systemType == 'ios') {
        api.openApp({
            iosUrl: url_,
            appParam: {}
        });
    } else {
        api.openApp({
            androidPkg: 'android.intent.action.VIEW',
            uri: url_
        }, function (ret, err) {
            // if (ret) {
            //     console.log(JSON.stringify(ret));
            // } else {
            //     console.log(JSON.stringify(err));
            // }
        });
    }
}

function initRefresh(opts_) {//下拉刷新
    api.setRefreshHeaderInfo({
        visible: true,
        loadingImg: 'widget://image/refresh2.png',
        bgColor: opts_.bgColor ? opts_.bgColor : '#fff',
        textColor: '#9d9d9d',
        textDown: '松开刷新...',
        textUp: '松开刷新...',
        textLoading: '加载中...',
        showTime: false
    }, function (ret, err) {
        // 检查网络是否连通
        if (api.connectionType == 'none') {
            api.toast({
                msg: '网络不可用',
                duration: 2000,
                location: 'middle'
            });
            api.refreshHeaderLoadDone();
            return false;
        }

        // 获取接口公用的接口参数
        commonParam = getCommonParam();
        optParam = '';

        // 当前页面重置为0
        curPage = 0;

        // 设置下拉刷新组件为刷新中状态
        api.refreshHeaderLoading();

        if (opts_ && opts_.callback) {//下拉刷新回调，响应动作
            opts_.callback();
        }
    });
}
function addLoadMoreEvent(opts_) { // 上拉加载更多
    var isLoadingData = false;//是否请求加载数据中
    var mediaItem = $api.dom('.media-item');
    var thresholdVal = mediaItem ? ($api.offset($api.dom('.media-item')).h) * 2 : 0;//设置距离底部多少距离时触发
    api.addEventListener({
        name: 'scrolltobottom',
        extra: {
            threshold: thresholdVal
        }
    }, function (ret, err) {
        isLoadingData = $api.dom('.loading-wrap');//获取loading元素，有即正在发起ajax中
        if (!isLastPage && !isLoadingData) {
            $api.addCls(pushTxt, 'dn');
            $api.removeCls(loadingMore, 'dn');
            // 检查网络是否连通
            if (api.connectionType == 'none') {
                // 加1s延时，视觉上可看到1s的加载更多加载中状态
                setTimeout(function () {
                    $api.addCls(loadingMore, 'dn');
                    $api.removeCls(pushTxt, 'dn');
                    api.toast({
                        msg: '网络不可用',
                        duration: 2000,
                        location: 'middle'
                    });
                }, 1000)
                return false;
            }
            if (opts_ && opts_.callback) {//上拉加载更多回调，响应动作
                opts_.callback();
            }
        }
    });
}
// app动态权限控制
// perm_: 请求单个或多个权限（逗号分隔）
// opts_.callback: 请求的权限已全部允许,执行回调
function confirmPermission(perm_, opts_) {
    var permArr = perm_.split(',');
    var hasPerm = api.hasPermission({
        list: permArr
    });
    // console.log('hasPerm:'+JSON.stringify(hasPerm));
    var allGranted = true;//申请的权限是否全部已打开
    for (var i = 0; i < hasPerm.length; i++) {
        if (!hasPerm[i].granted) {
            allGranted = false;
            // api.confirm({
            //     title: '提醒',
            //     msg: '没有获得 ' + permTxt[hasPerm[i]['name']] + " 权限\n是否前往设置？",
            //     buttons: ['去设置', '取消']
            // }, function(ret, err) {
            //     if(1 == ret.buttonIndex){

            //     }
            // });
        }
    }
    if (!allGranted) {
        var permTxt = {
            'camera': '相机/拍照/录像',
            'contacts': '联系人读取/写入',
            'microphone': '麦克风',
            'photos': '相册',
            'location': '定位',
            'locationAlways': '后台定位，只支持iOS',
            'notification': '状态栏通知',
            'calendar': '日历读取/写入。只支持Android',
            'phone': '手机识别码',
            'storage': '本地存储'
        };
        api.requestPermission({
            list: permArr
        }, function (ret, err) {
            console.log(JSON.stringify(ret))
            var list = ret.list,
                curName = '';
            for (var i in list) {
                if (!list[i].granted) {
                    curName = list[i].name;
                    setTimeout(function () {
                        api.toast({
                            msg: '获取"' + permTxt[curName] + '"权限被拒，对应功能无法正常使用！',
                            duration: 60000,
                            location: 'middle',
                            global: true
                        });
                    }, 0)
                    break;
                } else if (i == list.length - 1) {
                    // console.log('用户允许获得权限');
                    // 请求的权限已全部允许,执行回调
                    opts_ && opts_.callback();
                }
            }
        })
    } else {
        // console.log('请求的权限已全部打开');
        // 请求的权限已全部打开,执行回调
        opts_ && opts_.callback();
    }
}

// 以分钟为单位，设置localStorage过期时间，用于存储服务器数据
// set参数expire可不传，setItem到期时间标识expire会标识为-1,get时无过期时间，直接返回set中的val
var localStorageUtil = {
    set: function (key, val, expire) {
        var exp = expire ? Date.now() + expire * 1000 * 60 : -1;
        localStorage.setItem(key, JSON.stringify({ value: val, expire: exp }));
        console.log('set ' + key + ':' + JSON.stringify({ value: val, expire: new Date(exp).toLocaleString() }));
    },
    get: function (key) {
        var data = localStorage.getItem(key);
        // console.log(data);

        if (!data) return null;

        var dataObj = JSON.parse(data);

        if (dataObj.expire == -1) return dataObj.value;

        if (Date.now() >= dataObj.expire) {
            localStorage.removeItem(key);
            return null;
        } else {
            return dataObj.value;
        }
    }
};


function openMaskFrame() {
    api.openFrame({
        name: 'mask',
        url: 'widget://html/login/shanyan_ios_mask.html',
        rect: {
            marginTop: 0,
            marginRight: 0,
            marginBottom: 0,
            marginLeft: 0
        },
        animation: {
            type: 'none'
        }
    });
}

// 显示/隐藏 frame模拟加载中
var loadingFrame = {
    getCurWinName: function () {
        var windows = api.windows(),
            curWinName = windows[windows.length - 1]['name'];
        // console.log('loadingFrame-当前显示的窗口:' + curWinName);
        return curWinName;
    },
    show: function (opts_) {
        if (opts_) {
            var args = $api.jsonToStr(opts_);
            api.execScript({
                name: this.getCurWinName(),
                script: 'loadingFrame.open(' + args + ');'
            })
        } else {
            api.execScript({
                name: this.getCurWinName(),
                script: 'loadingFrame.open();'
            })
        }
    },
    hide: function () {
        api.execScript({
            name: this.getCurWinName(),
            script: "api.closeFrame({ name: 'loading_frame'});"
        })
    },
    open: function (opts_) {
        // console.log(JSON.stringify(opts_))
        api.openFrame({
            name: 'loading_frame',
            url: 'widget://html/loading_frame.html',
            rect: {
                marginTop: 0,
                marginRight: 0,
                marginBottom: 0,
                marginLeft: 0
            },
            animation: {
                type: 'none'
            },
            pageParam: opts_
        });
    }
};

// 显示/隐藏 frame模拟加载中
var loginFrame = {
    // getCurWinName: function () {
    //     var windows = api.windows(),
    //         curWinName = windows[windows.length - 1]['name'];
    //     console.log('窗口:' + JSON.stringify(windows));
    //     console.log('frame:' + JSON.stringify(api.frames()));
    //     console.log('loginFrame-当前显示的窗口:' + curWinName);
    //     return curWinName;
    // },
    show: function (opts_) {
        // if (opts_) {
        //     var args = $api.jsonToStr(opts_);
        //     api.execScript({
        //         name: this.getCurWinName(),
        //         frameName:'category_frame',
        //         script: 'loginFrame.open(' + args + ');'
        //     })
        // } else {
        //     api.execScript({
        //         name: this.getCurWinName(),
        //         frameName: 'category_frame',
        //         script: 'loginFrame.open();'
        //     })
        // }
        
        // console.log('frameName:'+api.frameName)
        console.log('loginFrame.show:' + JSON.stringify(opts_))
        api.openFrame({
            name: 'login_frame',
            url: 'widget://html/login/login.html',
            allowEdit:true,
            softInputMode:'resize',
            rect: {
                marginTop: 0,
                marginRight: 0,
                marginBottom: 0,
                marginLeft: 0
            },
            animation: {
                type: 'none'
            },
            pageParam: opts_
        });
    },
    hide: function () {
        // api.execScript({
        //     name: this.getCurWinName(),
        //     script: "api.closeFrame({ name: 'login_frame'});"
        // })
        api.execScript({
            frameName: 'login_frame',
            script: "login.closePopup();"
        })
    },
    open: function (opts_) {
        // console.log(JSON.stringify(opts_))
        
    }
};

function wakeUpQQ(qq_) {//拉起QQ客服对话窗口
    var openUrl = '';
    if (api.systemType == 'ios') {
        openUrl = 'mqq://im/chat?chat_type=wpa&uin=' + qq_ + '&version=1&src_type=web';
        // qqPlus模块
        qq = api.require('QQPlus');
        qq.installed(function (ret, err) {
            if (!ret.status) {
                alert('当前设备没有安装QQ客户端');
            }
        });
    } else {
        openUrl = 'mqqwpa://im/chat?chat_type=wpa&uin=' + qq_;
    }
    // console.log(openUrl);
    // 不加_parent声明，首次点击后无法再拉起QQ对话窗口
    window.open(openUrl, '_parent');

}

// 打开专辑播放页
/*  
aid_：必传
opts_:可选，参数
    course_type: 课程类型,
    jumptotab: 默认跳转到第N个tab,
    aid: 课程id,
    jumptovid: 自动跳转播放的视频id
*/
function openCourseDetailWin(aid_, opts_) {
    var params=opts_ || {};
    params.aid=aid_;
    console.log('openCourseDetailWin pageParam:' + JSON.stringify(params));
    console.log('openCourseDetailWin opts_:' + JSON.stringify(opts_));
    var course_type = 1, name, url;
    if (opts_ && opts_.hasOwnProperty('course_type')) course_type = opts_.course_type
    if (course_type == 8) {
        name = 'li'
        url = 'widget://html/course/li.html'
    } else {
        name = 'course_detail'
        url = 'widget://html/course/course_detail.html'
    }

    openNavWin({
        name: name,
        url: url,
        pageParam: params,
        bounces: false,
        slidBackType: 'edge',
        hideNavigationBar:true,
        autoAddEvent:false
    })
}

// 生成专辑章节视频播放权限修改时间映射表,用于与本地video.php缓存文件的video_optime字段比对，确认是否要获取最新服务器接口数据
function setVideosOptime(coursedata_) {
    var videosOptime = {},
        videos = [],
        videoList = coursedata_.data.video_list;
    for (var prop in videoList) {
        videos = videoList[prop]['videos'];
        for (var i = 0; i < videos.length; i++) {
            videosOptime[videos[i]['video_id']] = videos[i]['video_modify_time']
        }
    }
    // console.log('videosOptime:' + JSON.stringify(videosOptime))
    return videosOptime;
}

// 设置专辑详情页接口数据缓存文件路径
function setAlbumCacheDir(aid_) {
    //接口数据缓存文件路径前缀目录名：未登录，/visitor/（游客）;已登录，/zxb_id/(用户zxb_id)
    albumCachePrefixDir = 'visitor';

    var userInfo = $api.getPrefs('userInfo');
    if (userInfo) {
        albumCachePrefixDir = userInfo.zxb_id;
    }
    // 专辑详情接口数据缓存文件路径
    albumCacheDir = '/' + albumCachePrefixDir + '/album/' + aid_;
    albumCachePath = albumCacheDir + '/a_' + aid_;//如：/visitor/album/6444/a_6444.json
    videoCachePath = albumCacheDir + '/video/v_';//如：/visitor/album/6444/video/v_123.json
    liCachePath = '/' + albumCachePrefixDir + '/li/' + aid_;
    liCachePath = liCachePath + '/li_' + aid_;//如：/visitor/li/6444/li_6444.json

}
// 清除单个vid_缓存文件
function removeVideoCache(vid_) {
    // 清除video接口数据缓存文件
    var fs = api.require('fs');
    var rmfileResult = fs.removeSync({
        path: 'cache://' + videoCachePath + vid_ + '.json'
    });
    if (rmfileResult.status) {
        // console.log('video:' + vid_+'接口缓存文件清除成功：' + JSON.stringify(rmfileResult));
    } else {
        // console.log('video:' + vid_ +'接口缓存文件清除失败：' + JSON.stringify(rmfileResult));
    }
}

// 读取缓存文件
function readCache(path_, opts) {
    var success = opts.success,
        error = opts.error;
    api.readFile({
        path: 'cache://' + path_ + '.json'
    }, function (ret, err) {
        if (ret.status) {
            // console.log('从缓存文件' + path_ + '.json读取成功：'+new Date().toLocaleString())
            // console.log(ret.data)
            var data = $api.strToJson(ret.data);
            success && success(data);
        } else {
            // console.log('缓存文件' + path_ + '.json读取失败：'+JSON.stringify(err))
            error && error(err);
        }
    })
}
// 写入缓存文件
function writeCache(data_, path_, opts) {
    var success = opts.success,//写入缓存文件成功回调
        error = opts.error,//写入缓存文件失败回调
        saveOriginData = opts.saveOriginData;//是否要将服务器接口原始数据保存成缓存文件

    var dataStr = $api.jsonToStr(data_);

    // 存储服务器接口原始数据（用于判断'服务器接口数据是否有更新，需要二次渲染'）
    if (saveOriginData) {
        api.writeFile({
            path: 'cache://' + path_ + '_origin.json',
            data: dataStr
        }, function (ret, err) {
            if (ret.status) {
                // console.log('接口原始数据缓存文件' + path_ + '_origin.json写入成功！')
                success && success();
            } else {
                // console.log('接口原始数据缓存文件' + path_ + '_origin.json写入失败：' + JSON.stringify(err))
                error && error(err);
            }
        })
    }

    // 将远程图片缓存下来，替换服务器接口原始图片数据后存储(每缓存一张课程图片，写入一次缓存文件)
    var patt = /https?:\/\/[^"]*?\.(jpg|jpeg|png|gif)/gi,//匹配图片地址
        allImgs = dataStr.match(patt),
        allImgsLen = allImgs ? allImgs.length : 0,//需要缓存的图片数量
        tempData = dataStr,//存放'使用缓存图片替换远程图片'后的接口数据
        tempMap = {},//存储初始远程图片地址跟缓存后的图片路径一一影射关系
        imgCacheCount = 0;//统计已缓存的图片数量

    if (allImgsLen == 0) {
        // console.log('接口无图片需要缓存')
        api.writeFile({
            path: 'cache://' + path_ + '.json',
            data: dataStr
        }, function (ret, err) {
            if (ret.status) {
                // console.log('缓存文件' + path_ + '.json写入成功！')
                success && success();
            } else {
                // console.log('缓存文件' + path_ + '.json写入失败：' + JSON.stringify(err))
                error && error(err);
            }
        })
        return;
    }

    for (var i = 0; i < allImgsLen; i++) {
        (function (num) {
            api.imageCache({
                url: allImgs[num],
                thumbnail: false,
                policy: 'cache_only'
            }, function (ret, err) {
                // console.log(new Date().toLocaleTimeString()+'已缓存第i:' + num+'张图片')
                imgCacheCount++
                tempMap[allImgs[num]] = ret.url;
                // console.log(path_+' imgCacheCount:' + imgCacheCount)

                // console.log(JSON.stringify(tempMap))
                tempData = tempData.replace(allImgs[num], tempMap[allImgs[num]]);
                api.writeFile({
                    path: 'cache://' + path_ + '.json',
                    data: tempData
                }, function (ret, err) {
                    if (ret.status) {
                        // console.log(new Date().toLocaleTimeString()+' '+num+'缓存文件' + path_ + '.json写入成功！')
                        success && success();
                    } else {
                        // console.log(path_+'缓存文件' + path_ + '.json写入失败：' + JSON.stringify(err))
                        error && error(err);
                    }

                    if (imgCacheCount == allImgsLen) {
                        // console.log(path_+'全部远程图片已替换为缓存图片，完成缓存文件写入！')
                        // console.log($api.jsonToStr(tempData))
                    }
                })
            });
        })(i)
    }
}
// 将缓存文件内远程服务器图片地址逐一替换成本地缓存图片地址（）
function updateCacheFile(path_, opts) {
    var success = opts.success,//写入缓存文件成功回调
        error = opts.error;//写入缓存文件失败回调

    readCache(path_, {
        success: function (data_) {
            // console.log(new Date().toLocaleTimeString() +'updateCacheFile成功读取缓存文件' + path_)
            var dataStr = $api.jsonToStr(data_);
            // console.log(dataStr)

            // 将远程图片缓存下来，替换服务器接口原始图片数据后存储(每缓存一张课程图片，写入一次缓存文件)
            var patt = /https?:\/\/[^"]*?\.(jpg|jpeg|png|gif)/gi,//匹配图片地址
                allImgs = dataStr.match(patt),
                allImgsLen = allImgs ? allImgs.length : 0,//需要缓存的图片数量
                tempData = dataStr,//存放'使用缓存图片替换远程图片'后的接口数据
                tempMap = {},//存储初始远程图片地址跟缓存后的图片路径一一影射关系
                imgCacheCount = 0;//统计已缓存的图片数量

            if (allImgsLen == 0) {
                // console.log('缓存文件无远程图片需要缓存替换')
                return;
            }
            // console.log('有' + allImgsLen+'张远程图片需要缓存替换');

            for (var i = 0; i < allImgsLen; i++) {
                (function (num) {
                    api.imageCache({
                        url: allImgs[num],
                        thumbnail: false,
                        policy: 'cache_only'
                    }, function (ret, err) {
                        // console.log(new Date().toLocaleTimeString()+'updateCacheFile已缓存第i:' + num+'张图片')
                        imgCacheCount++
                        tempMap[allImgs[num]] = ret.url;
                        // console.log(path_ + ' updateCacheFile imgCacheCount:' + imgCacheCount)

                        // console.log(JSON.stringify(tempMap))
                        tempData = tempData.replace(allImgs[num], tempMap[allImgs[num]]);
                        api.writeFile({
                            path: 'cache://' + path_ + '.json',
                            data: tempData
                        }, function (ret, err) {
                            if (ret.status) {
                                // console.log(new Date().toLocaleTimeString()+' '+num+'updateCacheFile缓存文件' + path_ + '.json写入成功！')
                                success && success();
                            } else {
                                // console.log(path_ + 'updateCacheFile缓存文件' + path_ + '.json写入失败：' + JSON.stringify(err))
                                error && error(err);
                            }

                            if (imgCacheCount == allImgsLen) {
                                // console.log(path_ + 'updateCacheFile全部远程图片已替换为缓存图片，完成缓存文件写入！')
                                // console.log($api.jsonToStr(tempData))
                            }
                        })
                    });
                })(i)
            }

        },
        error: function () {
            console.log(new Date().toLocaleTimeString() + 'updateCacheFile读取缓存文件' + path_ + '失败！')
        }
    })


}

// 退出账号
function logout() {
    $api.removePrefs('userInfo');
    // 更新接口公用的接口参数
    commonParam = getCommonParam();

    api.execScript({
        name: 'main',
        frameName: 'home_frame',
        script: 'openFrame(4);'
    });
    api.closeToWin({
        name: 'main'
    })

    // 刷新VIP专区对应frame
    api.execScript({
        name: 'main',
        frameName: 'vip_frame',
        script: 'location.reload();'
    });
    // 刷新学习历史记录对应frame
    api.execScript({
        name: 'main',
        frameName: 'history_frame',
        script: 'location.reload();'
    });
    
    // 更新个人中心
    api.execScript({
        name: 'main',
        frameName: 'personal_frame',
        script: 'location.reload();'
    });

    // qqPlus模块
    // qq = api.require('QQPlus');
    // 注销登录状态
    // qq.logout(function (ret, err) {
        // if (ret.status) {
        //     alert('登出成功');
        // } else {
        //     alert(err.msg);
        // }
    // });

    //清除应用图标右上角数字
    // api.setAppIconBadge({
    //     badge: 0
    // });
}

// ajax请求
function ajaxRequest(opts) {
    var url = 'https://www.zixueb.cn/appapi';
    opts.url = opts.needPrefixUrl === false ? opts.url : (url + opts.url);

    // console.log(api.winName+' ajax url:' + opts.url)
    var complete = opts.complete,
        success = opts.success,
        error = opts.error,
        done = opts.done,
        autoHideLoading = opts.autoHideLoading,
        needReterror = opts.needReterror;//needReterror=true,即ret.error交由success回调处理

    if (opts.loading != false) {
        // 显示加载中
        showLoading(opts.loading);
    }
    api.ajax(opts, function (ret, err) {
        // 隐藏加载中
        if(autoHideLoading!=false){
            hideLoading();
        }
        // console.log('请求complete:'+new Date().toLocaleTimeString())
        complete && complete(opts, ret, err);
        if (ret) {
            // console.log('ajax请求数据成功：' + JSON.stringify(ret))
            if (ret.error && ((ret.error != 1 && ret.error != 30001) && !(needReterror === true))) { // 服务器请求成功 && (非30001“需要重新登录”(30001，重新登录，页面内success回调中执行) && 未显示声明为needReterror:true)
                hideLoading();
                api.toast({
                    msg: ret.msg,
                    duration: 2000,
                    location: 'middle'
                });
                return;
            }

            // console.log('ajax请求成功:' + opts.url)
            success && success(ret);
        } else {
            // console.log('ajax请求数据失败：' + JSON.stringify(err))
            if(error){
                error(err);
            }else{
                api.toast({
                    msg: err.msg,
                    duration: 4000,
                    location: 'middle'
                });
            }
        }
        // console.log('请求done:'+new Date().toLocaleTimeString())
        done && done(opts, ret, err);
    });
}

/**
 *打开'带通用顶部导航栏样式'的window,实现openWin的window+frame的结构
 * 调用openTabLayout，实现自动在打开的window中添加监听"导航栏左边返回按钮点击事件"
 * opt_: 必传，api.openTabLayout、api.openWin中支持的所有参数，可覆盖初始声明的默认任意openTabLayout window param属性
 * opt_新增额外参数解析，均为可选参数
 * autoAddEvent:默认true,若设为false,应在url所指window页面内自行添加navitembtn添加导航栏按钮点击监听事件
 * navLeftBtnCallback：导航栏左侧按钮点击回调事件，不传默认为关闭窗口
 * navRightBtnCallback：导航栏右侧按钮点击回调事件
 * 注意：navLeftBtnCallback/navRightBtnCallback回调是在url所指window页面内执行（navitembtn监听事件只能在url所指window页面内执行）！！！
**/
function openNavWin(opt_) {
    if (!opt_) return;
    var param = {
        title: '窗口标题',
        bgColor: '#fff',
        bounces: true,
        navigationBar: {
            color: '#fff',
            fontSize: 16,
            background: '#13aff0',
            leftButtons: [{
                iconPath: "widget://image/ico_back.png"
            }],
        },
        autoAddEvent: true,
        navLeftBtnCallback: null,
        navRightBtnCallback: null
    }
    if (opt_) {
        for (var i in opt_) {
            // console.log('opt_[' + i + ']:' + JSON.stringify(opt_[i]))
            if (i == 'navigationBar') {//navigationBar 只覆盖重新声明属性
                var navOpt_ = opt_[i];
                for (var j in navOpt_) {
                    param['navigationBar'][j] = navOpt_[j];
                }
            } else {
                param[i] = opt_[i];
            }

        }
    }

    // console.log('param:' + JSON.stringify(param))
    api.openTabLayout(param);


    if (opt_.autoAddEvent === false) return;//autoAddEvent若显示声明为false,不添加navLeftBtnCallback/navRightBtnCallback回调
    setTimeout(function () {//setTimeout确保openTabLayout窗口已打开
        var leftBtnCallback = opt_.navLeftBtnCallback ? opt_.navLeftBtnCallback : null,
            rightBtnCallback = opt_.navRightBtnCallback ? opt_.navRightBtnCallback : null;
        // navitembtn监听事件只能在url所指window页面内执行！！！
        api.execScript({
            name: opt_.name,
            script: 'addNavBackEvent(' + leftBtnCallback + ',' + rightBtnCallback + ')'
        })
    }, 400)
}
function addNavBackEvent(leftbtncallback_, rightbtncallback_) {
    // console.log('leftbtncallback_:' + leftbtncallback_)
    // console.log('rightbtncallback_:' + rightbtncallback_)
    api.addEventListener({
        name: 'navitembtn'
    }, function (ret, err) {
        console.log('监听成功，点击NavBar的按钮将由你的代码自定义处理');
        console.log('点击了按钮：' + ret.index + ', 类型：' + ret.type);

        if (ret.type == 'left' && 0 === ret.index) {
            if (leftbtncallback_) {
                leftbtncallback_(ret, err)
            } else {
                api.closeWin();
            }
        } else if (ret.type == 'right' && 0 === ret.index) {
            if (rightbtncallback_) {
                rightbtncallback_(ret, err)
            }
        }
    });
}

function openWriteOffWin() {
    api.openWin({
        name: 'browser',
        url: 'widget://browser/index2.html',
        pageParam: {
            url: 'https://www.zixueb.cn/appapi/include/write_off.php?noheader=1',
            styles: {
                title: '用户注销协议',
                showBackBtn: true,
                tabbar: false
            }
        }
    });
}

function openServiceAgreementWin() {
    api.openWin({
        name: 'browser',
        url: 'widget://browser/index2.html',
        pageParam: {
            url: 'https://www.zixueb.cn/appapi/include/service_agreement.php?noheader=1',
            styles: {
                title: '服务协议',
                showBackBtn: true,
                tabbar: false
            }
        }
    });
}
function openPrivacyWin() {
    api.openWin({
        name: 'browser',
        url: 'widget://browser/index2.html',
        pageParam: {
            url: 'https://www.zixueb.cn/appapi/include/privacy.php?noheader=1',
            styles: {
                title: '隐私政策',
                showBackBtn: true,
                tabbar: false
            }
        }
    });
}

function openVipAgreementWin() {
    api.openWin({
        name: 'browser',
        url: 'widget://browser/index2.html',
        pageParam: {
            url: 'https://www.zixueb.cn/appapi/include/vip_agreement.php?noheader=1',
            styles: {
                title: 'VIP会员服务协议',
                showBackBtn: true,
                tabbar: false
            }
        }
    });
}

function jpushExtraHandler(extra) {
    console.log($api.jsonToStr(extra))
    if(extra.course_id){
        openCourseDetailWin(extra.course_id,extra);
    }else if(extra.text){
        // var dialogBox = api.require('dialogBox');
        // dialogBox.scene({
        //     rect: {
        //         w: 280,
        //         h: 250
        //     },
        //     texts: {
        //         title: extra.title ? extra.title : '温馨提示',
        //         content: extra.text,
        //         okBtnTitle: extra.btnTitle ? extra.btnTitle : '知道了'
        //     },
        //     styles: {
        //         bg: '#fff',
        //         corner: 5,
        //         title: {
        //             bg: '#fff',
        //             h: 64,
        //             size: 20,
        //             color: '#000'
        //         },
        //         content: {
        //             color: '#666',
        //             size: 14,
        //             alignment: 'left'   
        //         },
        //         ok: {
        //             bg: '#13aff0',
        //             titleColor: '#fff',
        //             h: 40,
        //             titleSize: 14
        //         }
        //     }
        // }, function(ret, err) {
        //     var dialogBox = api.require('dialogBox');
        //     dialogBox.close({
        //         dialogName: 'scene'
        //     });
        // });

        var dialogBox = api.require('dialogBox');
        dialogBox.alert({
            texts: {
                title: extra.title ? extra.title : '温馨提示',
                content: extra.text,
                rightBtnTitle: extra.btnTitle ? extra.btnTitle : '知道了'
            },
            styles: {
                bg: '#fff',
                w: 300,
                corner:10,
                title: {
                    marginT: 36,
                    titleSize: 20,
                    titleColor: '#000'
                },
                content: {
                    color: '#666',
                    size: 14
                },
                right: {
                    marginB: 24,
                    marginL: 30,
                    w: 240,
                    h: 40,
                    corner: 20,
                    bg: '#13aff0',
                    size: 14,
                    color: '#fff'
                }
            }
        }, function(ret) {
            if (ret.eventType == 'right') {
                var dialogBox = api.require('dialogBox');
                dialogBox.close({
                    dialogName: 'alert'
                });
            }
        });
    }else if(extra.url){
        //内部浏览器打开
        api.openWin({
            name: 'browser',
            url: 'widget://browser/index2.html',
            pageParam: {
                url: extra.url,
                styles: {
                    title: extra.title ? extra.title : '自学帮',
                    showBackBtn: extra.showBackBtn ? extra.showBackBtn : false,
                    tabbar: extra.tabbar ? extra.tabbar : false
                }
            }
        });
    }
}

function updateFrameUserInfo(){
    // 刷新vip专区对应frame
    api.execScript({
        name: 'main',
        frameName: 'vip_frame',
        script: 'location.reload();'
    });
    // 刷新学习历史记录对应frame
    api.execScript({
        name: 'main',
        frameName: 'history_frame',
        script: 'location.reload();'
    });
    // 更新个人中心
    api.execScript({
        name: 'main',
        frameName: 'personal_frame',
        script: 'location.reload();'
    });
}

function conver(limit){  
    var size = "";  
    if( limit < 100 ){ //如果小于0.1KB转化成B  
        size = limit.toFixed(1) + "B";    
    }else if(limit < 100000 ){//如果小于0.1MB转化成KB  
        size = (limit / 1000).toFixed(1) + "KB";              
    }else if(limit < 100000000){ //如果小于0.1GB转化成MB  
        size = (limit / 1000000).toFixed(1) + "MB";  
    }else{ //其他转化成GB
        size = (limit / 1000000000).toFixed(1) + "GB";  
    }
    var sizestr = size + "";   
    var len = sizestr.indexOf("\.");  
    var dec = sizestr.substr(len + 1, 1);  
    if(dec == "0"){// 当小数点后为0时 去掉小数部分
        return sizestr.substring(0,len) + sizestr.substr(len + 2,2);  
    }
    return sizestr;  
}

function toTeacher(id){
    openNavWin({
        name:'teacher_detail',
        url:'widget://html/course/teacher_detail.html',
        title: '讲师介绍',
        pageParam: {
            member_id: id
        },
    })
}


function openEntrance(item_) {//item_:json对象
    /* 跳转类型定义,字段名：jump_type
     * 1：课程
     * 2：分类页 
     * 3: 内部浏览器打开
     * 4: 外部浏览器打开链接
    */
    var jumpType = item_.jump_type,
        jumpParam = item_.jump_param;
        console.log('item_111111111111', $api.jsonToStr(item_), jumpType, jumpParam)
    switch (Number(jumpType)) {
        case 1:
            openCourseDetailWin(jumpParam.course_id, jumpParam);
            break;
        case 2:
            switchToCategory(jumpParam);
            break;
        case 3:
            openInnerBroswer(jumpParam);
            break;
        case 4:
            openOutBroswer(jumpParam);
            break;
        default:
            break;
    }
}
function openInnerBroswer(jumpParam_) {
    //内部浏览器打开
    let commonParam = getCommonParam()
    commonParam = commonParam.replace('?', '&', commonParam)
    api.openWin({
        name: 'browser',
        url: 'widget://browser/index2.html',
        pageParam: {
            url: jumpParam_.url + commonParam,
            styles: {
                title: jumpParam_.title ? jumpParam_.title : '自学帮',
                showBackBtn: jumpParam_.showBackBtn ? jumpParam_.showBackBtn : false,
                tabbar: jumpParam_.tabbar ? jumpParam_.tabbar : false
            }
        }
    });
}
function openOutBroswer(jumpParam_) {
    //外部浏览器打开
    if (isIos) {
        api.openApp({ iosUrl: jumpParam_.url });
    } else {
        api.openApp({ uri: jumpParam_.url });
    }
}
function switchToCategory(jumpParam_) {
    console.log('jumpParam_:' + JSON.stringify(jumpParam_));
    var extraData = {
        defaultCatid: 14,
        filterSync: {
            first: 0,
            second: 0,
            third: 0
        },
        pageSync: {
            order: 0,
            course_type: 0,
            course_level_sort: 0
        }
    };
    if (jumpParam_) {
        extraData.defaultCatid = jumpParam_.cate_id;
        extraData.filterSync.first = jumpParam_.first_id;
        extraData.filterSync.second = jumpParam_.second_id;
        extraData.filterSync.third = jumpParam_.third_id;
        extraData.pageSync.order = jumpParam_.order;
        extraData.pageSync.course_type = jumpParam_.course_type;
        extraData.pageSync.course_level_sort = jumpParam_.course_level_sort;
    }

    openFrame(1);
    api.sendEvent({
        name: 'setTradeFrameGroupEvent',
        extra: extraData
    })
}

function openFrame(index_) {
    var index = Number(index_);
    // console.log('index:'+ index)

    switch (index) {
        case 0://首页
            api.setFrameGroupAttr({
                name: 'categoryListFrameGroup',
                hidden: true
            });
            api.setTabLayoutAttr({
                hideNavigationBar: false,
                animated: false,
            });
            api.setTabBarAttr({
                index: index,
            });
            break;
        case 1://分类
            api.setFrameGroupAttr({
                name: 'categoryListFrameGroup',
                hidden: false
            });
            api.setTabLayoutAttr({
                hideNavigationBar: false,
                animated: false,
            });
            api.setTabBarAttr({
                index: index,
            });
            break;
        case 2://VIP专区
            api.setFrameGroupAttr({
                name: 'categoryListFrameGroup',
                hidden: true
            });
            api.setTabLayoutAttr({
                hideNavigationBar: false,
                animated: false,
            });
            api.setTabBarAttr({
                index: index,
            });
            break;
        case 3://最近学习
            // if (!userInfo) {
            //     return false;
            // }
            api.setFrameGroupAttr({
                name: 'categoryListFrameGroup',
                hidden: true
            });
            api.setTabLayoutAttr({
                hideNavigationBar: false,
                animated: false,
            });
            api.setTabBarAttr({
                index: index,
            });
            break;
        case 4://我的
            // if (!userInfo) {
            //     return false;
            // }
            api.setFrameGroupAttr({
                name: 'categoryListFrameGroup',
                hidden: true
            });
            // setTabBarAttr、setTabLayoutAttr执行顺序不可调，否则从最近学习切换到我的frame时会看到"最近学习frame因隐藏navigationBar先上移再隐藏的闪现"现象
            api.setTabBarAttr({
                index: index,
            });
            api.setTabLayoutAttr({
                hideNavigationBar: true,
                animated: false,
            });
            break;
        default:
            break;
    }
    // api.setTabBarAttr({
    //     index: index,
    // });
}